//
//  MyView.m
//  PlaySongDemo
//
//  Created by zyqiong on 16/8/12.
//  Copyright © 2016年 zyqiong. All rights reserved.
//

#import "MyView.h"
#import "MarqueeLabel.h"

@interface MyView ()
@property (strong, nonatomic) UIView *backView;
@property (strong, nonatomic) UIButton *musicButton;
@property (strong, nonatomic) UIButton *pauseButton;
@property (strong, nonatomic) UIButton *nextButton;
@property (strong, nonatomic) MarqueeLabel *nameLabel;

@property (assign, nonatomic) BOOL isPlaying;

@end

@implementation MyView

- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.backView];
        [self addSubview:self.nextButton];
        [self addSubview:self.pauseButton];
        [self addSubview:self.nameLabel];
        [self addSubview:self.musicButton];
        self.isViewExtension = NO;
        self.isPlaying = YES;
    }
    return self;
}

- (void)layoutSubviews {
    [UIView animateWithDuration:.3 animations:^{
        self.backView.frame = self.bounds;
        CGFloat wh = 28;
        CGFloat x = self.frame.size.width - 4 - wh;
        CGFloat y = (self.frame.size.height - wh) * 0.5;
        self.nextButton.frame = CGRectMake(x, y, wh, wh);
        
        CGFloat pausex = self.frame.size.width - 4 -10 - wh * 2;
        CGFloat pausey = (self.frame.size.height - wh) * 0.5;
        self.pauseButton.frame = CGRectMake(pausex, pausey, wh, wh);
        
        CGFloat musicx = 4;
        CGFloat musicy = (self.frame.size.height - wh) * 0.5;
        self.musicButton.frame = CGRectMake(musicx, musicy, wh, wh);
        
        
    }];
    
}

- (void)startAnimail{
    CABasicAnimation *theAnimation;
    theAnimation=[CABasicAnimation animationWithKeyPath:@"transform.rotation.z"];
    theAnimation.duration=10;
    theAnimation.removedOnCompletion = NO;
    theAnimation.repeatCount = INTMAX_MAX;
    theAnimation.fromValue = [NSNumber numberWithFloat:0];
    theAnimation.toValue = [NSNumber numberWithFloat:M_PI*2];
    [self.musicButton.layer addAnimation:theAnimation forKey:@"playViewAnimateTransform"];
}

- (void)stopAnimail{
    [self.musicButton.layer removeAllAnimations];
}


- (void)setIsViewExtension:(BOOL)isViewExtension {
    _isViewExtension = isViewExtension;
    CGFloat alpha = 0.0;
    if (isViewExtension) {
        alpha = 1.0;
    }
    [UIView animateWithDuration:.3 animations:^{
        self.pauseButton.alpha = alpha;
        self.nextButton.alpha = alpha;
        self.nameLabel.alpha = alpha;
    }completion:^(BOOL finished) {
        self.pauseButton.hidden = !isViewExtension;
        self.nextButton.hidden = !isViewExtension;
        self.nameLabel.hidden = !isViewExtension;
    }];
    
}

- (void)playButtonClicked:(UIButton *)btn {
    if (self.clickedBack) {
        self.clickedBack(btn.tag);
    }
}

- (void)setIsPlaying:(BOOL)isPlaying {
    _isPlaying = isPlaying;
    if (isPlaying) {
        [self.pauseButton setImage:[UIImage imageNamed:@"video_music_pause"] forState:UIControlStateNormal];
        [self startAnimail];
    } else {
        [self.pauseButton setImage:[UIImage imageNamed:@"video_music_play"] forState:UIControlStateNormal];
        [self stopAnimail];
    }
}

- (void)pauseButtonClicked:(UIButton *)btn  {
    
    self.isPlaying = !self.isPlaying;
    
    if (self.clickedBack) {
        self.clickedBack(btn.tag);
    }
}
- (void)nextButtonClicked:(UIButton *)btn  {
    NSLog(@"点击了下一首按钮");
    if (self.clickedBack) {
        self.clickedBack(btn.tag);
    }
}

- (MarqueeLabel *)nameLabel {
    if (_nameLabel == nil) {
        CGFloat wh = 28;
        CGFloat width = self.frame.size.width - 3 * wh - 4 -2 - 10 * 2- 4;
        CGFloat height = self.frame.size.height;
        width = [UIScreen mainScreen].bounds.size.width - 136 - 14 * 3 - 30;
        CGFloat x = 4+ wh + 2;
        MarqueeLabel *name = [[MarqueeLabel alloc] initWithFrame:CGRectMake(x, 0, width, height) duration:20.0f andFadeLength:10.0f];
        name.textAlignment = NSTextAlignmentCenter;
        name.font = [UIFont systemFontOfSize:15];
        name.textColor = [UIColor whiteColor];
        name.text = @"乌鸦喝水";
//        name.marqueeType = MLContinuous;
        _nameLabel = name;
    }
    return _nameLabel;
}


- (UIView *)backView {
    if (_backView == nil) {
        UIView *back = [[UIView alloc] initWithFrame:self.bounds];
        back.backgroundColor = [UIColor colorWithRed:0/255.0 green:0/255.0 blue:0/255.0 alpha:.5];
        back.layer.cornerRadius = back.frame.size.height * 0.5;
        back.layer.masksToBounds = YES;
        _backView = back;
    }
    return _backView;
}

// 下一首
- (UIButton *)nextButton {
    if (_nextButton == nil) {
        CGFloat wh = 28;
        CGFloat x = self.frame.size.width - 4 - wh;
        CGFloat y = (self.frame.size.height - wh) * 0.5;
        UIButton *music = [[UIButton alloc] initWithFrame:CGRectMake(x, y, wh , wh)];
        [music setImage:[UIImage imageNamed:@"video_music_next"] forState:UIControlStateNormal];
        [music addTarget:self action:@selector(nextButtonClicked:) forControlEvents:UIControlEventTouchUpInside];
        music.tag = 10;
        _nextButton = music;
    }
    return _nextButton;
}

// 暂停
- (UIButton *)pauseButton {
    if (_pauseButton == nil) {
        CGFloat wh = 28;
        CGFloat x = self.frame.size.width - 4 -10 - wh * 2;
        CGFloat y = (self.frame.size.height - wh) * 0.5;
        UIButton *music = [[UIButton alloc] initWithFrame:CGRectMake(x, y, wh , wh)];
        [music setImage:[UIImage imageNamed:@"video_music_pause"] forState:UIControlStateNormal];
        [music addTarget:self action:@selector(pauseButtonClicked:) forControlEvents:UIControlEventTouchUpInside];
        music.tag = 11;
        _pauseButton = music;
    }
    return _pauseButton;
}


- (UIButton *)musicButton {
    if (_musicButton == nil) {
        CGFloat wh = 28;
        CGFloat x = 4;
        CGFloat y = (self.frame.size.height - wh) * 0.5;
        UIButton *music = [[UIButton alloc] initWithFrame:CGRectMake(x, y, wh , wh)];
        [music setImage:[UIImage imageNamed:@"video_music"] forState:UIControlStateNormal];
        [music addTarget:self action:@selector(playButtonClicked:) forControlEvents:UIControlEventTouchUpInside];
        music.tag = 12;
        _musicButton = music;
    }
    return _musicButton;
}


@end
